@@ -21,21 +21,35 @@
 
 #include <gio/gio.h>
 
+#include "gl-application.h"
+#include "gl-journal.h"
+
 typedef enum
 {
     GL_QUERY_SEARCH_TYPE_SUBSTRING,
     GL_QUERY_SEARCH_TYPE_EXACT
 } GlQuerySearchType;
 
+typedef enum
+{
+    GL_ROW_ENTRY_TYPE_UNCOMPRESSED,
+    GL_ROW_ENTRY_TYPE_COMPRESSED,
+    GL_ROW_ENTRY_TYPE_HEADER
+} GlRowEntryType;
+
 /* Resultant query passed to journal model from eventviewlist */
 typedef struct GlQuery
 {
     GPtrArray *queryitems;   /* array of GlQueryItem structs */
     GlQuerySearchType search_type;    /* indicates if search field is passed as exact match */
+    GlSortOrder order; /* whether to iterate through journal in ascending or descending timestamp order */
     guint64 start_timestamp;
     guint64 end_timestamp;
 } GlQuery;
 
+#define GL_TYPE_ROW_ENTRY gl_row_entry_get_type()
+G_DECLARE_FINAL_TYPE (GlRowEntry, gl_row_entry, GL, ROW_ENTRY, GObject)
+
 #define GL_TYPE_JOURNAL_MODEL gl_journal_model_get_type()
 G_DECLARE_FINAL_TYPE (GlJournalModel, gl_journal_model, GL, JOURNAL_MODEL, GObject)
 
@@ -43,6 +57,8 @@ GlJournalModel *        gl_journal_model_new                            (void);
 
 GlQuery *               gl_query_new                                    (void);
 
+GlRowEntry *            gl_row_entry_new                                (void);
+
 void                    gl_journal_model_take_query                     (GlJournalModel *model,
                                                                          GlQuery *query);
 
@@ -71,4 +87,13 @@ gchar *                 gl_journal_model_get_boot_time                  (GlJourn
 void                    gl_query_set_search_type                        (GlQuery *query,
                                                                          GlQuerySearchType search_type);
 
+void                    gl_query_set_sort_order                         (GlQuery *query,
+                                                                         GlSortOrder order);
+
+GlJournalEntry *        gl_row_entry_get_journal_entry                  (GlRowEntry *entry);
+
+GlRowEntryType          gl_row_entry_get_row_type                       (GlRowEntry *entry);
+
+guint                   gl_row_entry_get_compressed_entries             (GlRowEntry *entry);
+
 #endif
