@@ -94,8 +94,7 @@ gl_journal_update_latest_timestamp (GlJournal *journal)
         g_warning ("Error retrieving the sender timestamps: %s",
                    g_strerror (-r));
     }
-
-    if (realtime > boot_id->realtime_last)
+    else if (realtime > boot_id->realtime_last)
     {
         boot_id->realtime_last = realtime;
     }
@@ -343,6 +342,8 @@ gl_journal_finalize (GObject *object)
         g_free (boot_id->boot_match);
     }
     g_array_free (priv->boot_ids, TRUE);
+
+    G_OBJECT_CLASS (gl_journal_parent_class)->finalize (object);
 }
 
 static void
